pub struct BlockData<B> {
pub header: B,
pub body: Bytes,
}Expand description
Simplex header bytes plus arbitrary body bytes that ride with them.
The header portion is the only part covered by the certificate digest. The body portion can carry transactions or other non-certified data that should be fetched and streamed with the header bytes.
Fields
header: Bbody: BytesImplementations