MarshalResolver

Struct MarshalResolver 

pub struct MarshalResolver<D: Digest, P: PublicKey> { /* private fields */ }
Store-backed resolver for Commonware marshal requests.

Unlike the P2P resolver, this resolves marshal backfill requests directly from an Exoware Simplex store and delivers responses into Marshal’s local resolver handler.

Implementations

Source

impl<D, P> MarshalResolver<D, P>
where D: Digest + Send + 'static, P: PublicKey,

pub fn init<E>( context: E, mailbox_size: NonZeroUsize, client: SimplexClient, ) -> (Receiver<D>, Self)
where E: Clock + Metrics + Spawner,

pub fn new<E>( context: E, mailbox_size: NonZeroUsize, client: SimplexClient, handler: MarshalHandler<D>, ) -> Self
where E: Clock + Metrics + Spawner,

pub const fn client(&self) -> &SimplexClient

pub fn into_client(self) -> SimplexClient