pub struct MarshalResolver<D: Digest, P: PublicKey> { /* private fields */ }Expand description
Store-backed resolver for Commonware marshal requests.
Unlike the P2P resolver, this resolves marshal backfill requests directly from an Exoware Simplex store and delivers responses into Marshal’s local resolver handler.
Implementations
Sourceimpl<D, P> MarshalResolver<D, P>
impl<D, P> MarshalResolver<D, P>
pub fn init<E>( context: E, mailbox_size: NonZeroUsize, client: SimplexClient, ) -> (Receiver<D>, Self)
pub fn new<E>( context: E, mailbox_size: NonZeroUsize, client: SimplexClient, handler: MarshalHandler<D>, ) -> Self
pub const fn client(&self) -> &SimplexClient
pub fn into_client(self) -> SimplexClient